@@ -1,7 +1,12 @@
 package Code::Includable::Tree::FromStruct;
 
-our $DATE = '2016-04-14'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2016-11-23'; # DATE
+our $VERSION = '0.11'; # VERSION
+
+our $GET_PARENT_METHOD = 'parent';
+our $GET_CHILDREN_METHOD = 'children';
+our $SET_PARENT_METHOD = 'parent';
+our $SET_CHILDREN_METHOD = 'children';
 
 sub new_from_struct {
     my $class = shift;
@@ -37,7 +42,7 @@ sub new_from_struct {
     }
 
     # connect node to parent
-    $node->parent($struct->{_parent}) if $struct->{_parent};
+    $node->$SET_PARENT_METHOD($struct->{_parent}) if $struct->{_parent};
 
     # create children
     if ($struct->{_children}) {
@@ -58,7 +63,7 @@ sub new_from_struct {
             );
         }
         # connect node to children
-        $node->children(\@children);
+        $node->$SET_CHILDREN_METHOD(\@children);
     }
 
     $node;
@@ -79,7 +84,7 @@ Code::Includable::Tree::FromStruct - Routine to build tree object from data stru
 
 =head1 VERSION
 
-This document describes version 0.10 of Code::Includable::Tree::FromStruct (from Perl distribution Role-TinyCommons-Tree), released on 2016-04-14.
+This document describes version 0.11 of Code::Includable::Tree::FromStruct (from Perl distribution Role-TinyCommons-Tree), released on 2016-11-23.
 
 =for Pod::Coverage .+
 
@@ -95,6 +100,28 @@ object as the first argument, e.g.:
 The full documentation about the routines is in
 L<Role::TinyCommons::Tree::FromStruct>.
 
+=head1 VARIABLES
+
+=head2 $GET_PARENT_METHOD => str (default: parent)
+
+The method names C<parent> can actually be customized by (locally) setting this
+variable and/or C<$SET_PARENT_METHOD>.
+
+=head2 $SET_PARENT_METHOD => str (default: parent)
+
+The method names C<parent> can actually be customized by (locally) setting this
+variable and/or C<$GET_PARENT_METHOD>.
+
+=head2 $GET_CHILDREN_METHOD => str (default: children)
+
+The method names C<children> can actually be customized by (locally) setting
+this variable and C<$SET_CHILDREN_METHOD>.
+
+=head2 $SET_CHILDREN_METHOD => str (default: children)
+
+The method names C<children> can actually be customized by (locally) setting
+this variable and C<$GET_CHILDREN_METHOD>.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Role-TinyCommons-Tree>.
