@@ -1,7 +1,12 @@
 package Code::Includable::Tree::NodeMethods;
 
-our $DATE = '2016-04-14'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2016-11-23'; # DATE
+our $VERSION = '0.11'; # VERSION
+
+our $GET_PARENT_METHOD = 'parent';
+our $GET_CHILDREN_METHOD = 'children';
+our $SET_PARENT_METHOD = 'parent';
+our $SET_CHILDREN_METHOD = 'children';
 
 # we must contain no other functions
 
@@ -10,7 +15,7 @@ use Scalar::Util ();
 # like children, but always return list
 sub _children_as_list {
     my $self = shift;
-    my @c = $self->children;
+    my @c = $self->$GET_CHILDREN_METHOD;
     if (@c == 1) {
         return () unless defined($c[0]);
         return @{$c[0]} if ref($c[0]) eq 'ARRAY';
@@ -35,10 +40,10 @@ sub descendants {
 sub ancestors {
     my $self = shift;
     my @res;
-    my $p = $self->parent;
+    my $p = $self->$GET_PARENT_METHOD;
     while ($p) {
         push @res, $p;
-        $p = $p->parent;
+        $p = $p->$GET_PARENT_METHOD;
     }
     @res;
 }
@@ -60,7 +65,7 @@ sub first_node {
 
 sub is_first_child {
     my $self = shift;
-    my $parent = $self->parent;
+    my $parent = $self->$GET_PARENT_METHOD;
     return 0 unless $parent;
     my @c = _children_as_list($parent);
     @c && Scalar::Util::refaddr($self) == Scalar::Util::refaddr($c[0]);
@@ -68,7 +73,7 @@ sub is_first_child {
 
 sub is_last_child {
     my $self = shift;
-    my $parent = $self->parent;
+    my $parent = $self->$GET_PARENT_METHOD;
     return 0 unless $parent;
     my @c = _children_as_list($parent);
     @c && Scalar::Util::refaddr($self) == Scalar::Util::refaddr($c[-1]);
@@ -76,7 +81,7 @@ sub is_last_child {
 
 sub is_only_child {
     my $self = shift;
-    my $parent = $self->parent;
+    my $parent = $self->$GET_PARENT_METHOD;
     return 0 unless $parent;
     my @c = _children_as_list($parent);
     @c==1;# && Scalar::Util::refaddr($self) == Scalar::Util::refaddr($c[0]);
@@ -84,7 +89,7 @@ sub is_only_child {
 
 sub is_nth_child {
     my ($self, $n) = @_;
-    my $parent = $self->parent;
+    my $parent = $self->$GET_PARENT_METHOD;
     return 0 unless $parent;
     my @c = _children_as_list($parent);
     @c >= $n && Scalar::Util::refaddr($self) == Scalar::Util::refaddr($c[$n-1]);
@@ -92,7 +97,7 @@ sub is_nth_child {
 
 sub is_nth_last_child {
     my ($self, $n) = @_;
-    my $parent = $self->parent;
+    my $parent = $self->$GET_PARENT_METHOD;
     return 0 unless $parent;
     my @c = _children_as_list($parent);
     @c >= $n && Scalar::Util::refaddr($self) == Scalar::Util::refaddr($c[-$n]);
@@ -100,7 +105,7 @@ sub is_nth_last_child {
 
 sub is_first_child_of_type {
     my $self = shift;
-    my $parent = $self->parent;
+    my $parent = $self->$GET_PARENT_METHOD;
     return 0 unless $parent;
     my $type = ref($self);
     my @c = grep { ref($_) eq $type } _children_as_list($parent);
@@ -109,7 +114,7 @@ sub is_first_child_of_type {
 
 sub is_last_child_of_type {
     my $self = shift;
-    my $parent = $self->parent;
+    my $parent = $self->$GET_PARENT_METHOD;
     return 0 unless $parent;
     my $type = ref($self);
     my @c = grep { ref($_) eq $type } _children_as_list($parent);
@@ -118,7 +123,7 @@ sub is_last_child_of_type {
 
 sub is_only_child_of_type {
     my $self = shift;
-    my $parent = $self->parent;
+    my $parent = $self->$GET_PARENT_METHOD;
     return 0 unless $parent;
     my $type = ref($self);
     my @c = grep { ref($_) eq $type } _children_as_list($parent);
@@ -127,7 +132,7 @@ sub is_only_child_of_type {
 
 sub is_nth_child_of_type {
     my ($self, $n) = @_;
-    my $parent = $self->parent;
+    my $parent = $self->$GET_PARENT_METHOD;
     return 0 unless $parent;
     my $type = ref($self);
     my @c = grep { ref($_) eq $type } _children_as_list($parent);
@@ -136,7 +141,7 @@ sub is_nth_child_of_type {
 
 sub is_nth_last_child_of_type {
     my ($self, $n) = @_;
-    my $parent = $self->parent;
+    my $parent = $self->$GET_PARENT_METHOD;
     return 0 unless $parent;
     my $type = ref($self);
     my @c = grep { ref($_) eq $type } _children_as_list($parent);
@@ -145,7 +150,7 @@ sub is_nth_last_child_of_type {
 
 sub prev_sibling {
     my $self = shift;
-    my $parent = $self->parent or return undef;
+    my $parent = $self->$GET_PARENT_METHOD or return undef;
     my $refaddr = Scalar::Util::refaddr($self);
     my @c = _children_as_list($parent);
     for my $i (1..$#c) {
@@ -158,7 +163,7 @@ sub prev_sibling {
 
 sub prev_siblings {
     my $self = shift;
-    my $parent = $self->parent or return ();
+    my $parent = $self->$GET_PARENT_METHOD or return ();
     my $refaddr = Scalar::Util::refaddr($self);
     my @c = _children_as_list($parent);
     for my $i (1..$#c) {
@@ -171,7 +176,7 @@ sub prev_siblings {
 
 sub next_sibling {
     my $self = shift;
-    my $parent = $self->parent or return undef;
+    my $parent = $self->$GET_PARENT_METHOD or return undef;
     my $refaddr = Scalar::Util::refaddr($self);
     my @c = _children_as_list($parent);
     for my $i (0..$#c-1) {
@@ -184,7 +189,7 @@ sub next_sibling {
 
 sub next_siblings {
     my $self = shift;
-    my $parent = $self->parent or return ();
+    my $parent = $self->$GET_PARENT_METHOD or return ();
     my $refaddr = Scalar::Util::refaddr($self);
     my @c = _children_as_list($parent);
     for my $i (0..$#c-1) {
@@ -210,7 +215,7 @@ Code::Includable::Tree::NodeMethods - Tree node routines
 
 =head1 VERSION
 
-This document describes version 0.10 of Code::Includable::Tree::NodeMethods (from Perl distribution Role-TinyCommons-Tree), released on 2016-04-14.
+This document describes version 0.11 of Code::Includable::Tree::NodeMethods (from Perl distribution Role-TinyCommons-Tree), released on 2016-11-23.
 
 =head1 DESCRIPTION
 
@@ -225,6 +230,28 @@ object as the first argument, e.g.:
 
 =for Pod::Coverage .+
 
+=head1 VARIABLES
+
+=head2 $GET_PARENT_METHOD => str (default: parent)
+
+The method names C<parent> can actually be customized by (locally) setting this
+variable and/or C<$SET_PARENT_METHOD>.
+
+=head2 $SET_PARENT_METHOD => str (default: parent)
+
+The method names C<parent> can actually be customized by (locally) setting this
+variable and/or C<$GET_PARENT_METHOD>.
+
+=head2 $GET_CHILDREN_METHOD => str (default: children)
+
+The method names C<children> can actually be customized by (locally) setting
+this variable and C<$SET_CHILDREN_METHOD>.
+
+=head2 $SET_CHILDREN_METHOD => str (default: children)
+
+The method names C<children> can actually be customized by (locally) setting
+this variable and C<$GET_CHILDREN_METHOD>.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Role-TinyCommons-Tree>.
